@@ -93,7 +93,7 @@ frdAllPairsSiegelTest.default <-
        # GRPNAMES <- as.character(levels(groups))
         k <- nlevels(groups)
         n <- nlevels(blocks)
-        GRPNAMES <- as.character(groups[1:k])
+        GRPNAMES <- levels(groups)
     }
 
     p.adjust.method = match.arg(p.adjust.method)
