@@ -104,7 +104,7 @@ frdManyOneExactTest.default <-
         blocks <- factor(blocks)
         k <- nlevels(groups)
         n <- nlevels(blocks)
-        GRPNAMES <- as.character(groups[1:k])
+        GRPNAMES <- levels(groups)
     }
 
     ## Check arguments
